import {
  select,
  scaleBand,
  scaleLinear,
  csv,
  extent,
  autoType,
  range,
  axisBottom,
  axisLeft,
  rangeRound,
  max,
} from 'd3';

const options = ['revenue', 'profit'];

const width = 900;
const height = 490;

const margin = {
  top: 70,
  right: 0,
  bottom: 30,
  left: 50,
};

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const dropDown = select('body')
  .append('select')
  .attr('id', 'my-select')
  .selectAll('option')
  .data(options)
  .join('option')
  .text((d) => d)
  .property('value', (d) => d);

const main = async () => {
  const data = await csv(
    'revenues.csv',
    autoType
  );

  let yValue = (d, selectedOption) => {
    return selectedOption === undefined
      ? d.revenue
      : d[selectedOption];
  };
  const xValue = (d) => d.month;

  const x = scaleBand()
    .domain(data.map((d) => d.month))
    .rangeRound([
      margin.left,
      width - margin.right,
    ])
    .padding(0.1);

  const y = scaleLinear()
    .domain([0, max(data, (d) => d.revenue)])
    .range([height - margin.bottom, 0]);
  
  console.log(y.domain())

  const marks = data.map((d) => {
    return {
      x: x(xValue(d)),
      y: y(yValue(d)),
    };
  });
  
 

  svg
    .append('g')
    .attr(
      'transform',
      `translate(0, ${height - margin.bottom})`
    )
    .call(axisBottom(x));
  svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left}, 0)`
    )
  	.attr('class', 'y-axis')
    .call(axisLeft(y).ticks(null, '$2f'));



function update(selectedOption){
  const t = d3.transition().duration(750);
		y.domain([0, max(data, (d) => d[selectedOption])]);
		
  	const newMarks = data.map((d) => ({
    x: x(xValue(d)),
    y: d[selectedOption]
    }))
    
  	// svg
  	// .selectAll('rect')
  	// .data(newMarks)
  	// .join('rect')
  	// .attr('fill', 'steelblue')
  	// .attr('y', (d) => y(d.y))
  	// .attr('x', (d) => d.x)
  	// .attr('width', x.bandwidth())
  	// .attr('height', (d) => y(0) - y(d.y))
  
  
  svg.selectAll('rect')
  	.data(newMarks)
    .join(
				enter => 
        	enter
          	.append('rect')
            	.attr('fill', 'steelblue')
            	.attr('y', y(0))
    					.attr('x', (d) => d.x)
    					.attr('width', x.bandwidth())
              .attr('height', 0)
    					.call(enter => enter.transition(t)
                   .attr('y', (d) => y(d.y))
                   .attr('height', (d) => y(0) - y(d.y))
                   ),
    				update
              
              	
    )
  
}
  
  update('revenue');
  
  

  
  
  select('#my-select').on(
    'change',
    function (d) {
    	let selectedOption = select(this).property('value');
     // y.domain([0, max(data, (d) => d[selectedOption])])
     //  svg.selectAll('g.y-axis')
     //  	.transition().duration(1000).call(axisLeft(y));
      update(selectedOption);
    }
  );
};

main();
